EDuke32 Changelog Archivio non ufficiale

Cosa è cambiato in EDuke32, build per build

2.117 build · 8.866 commit · 25 autori · Ottobre 2009 – Agosto 2026

Commit per anno

Stai vedendo il 2012 · selezionalo di nuovo per vedere tutti gli anni
Era SVN · r1519 – r8798 Era Git · voidpoint.io, da aprile 2020
Filtri · 2 attivi

Visualizzate 1 build · 4 commit

Esporta CSV
Opzioni di visualizzazione
Dettagli dei commit:

Luglio 2012 1 build · 4 commit

Build 2834

13 lug 2012 · 9 commit · 1 autore SVN
Apri la build
  • VP8

    clamp GL texture to edge if possible, preventing potential stray lines

    Helixhorned r2834 13 lug, 11:21
  • VP8

    don't call I_ClearAllInput() before idle loop.

    Helixhorned r2833 13 lug, 11:20
    Mostra dettagli

    If input is cleared before, it can become impossible to cancel the video when decoding and displaying a frame takes longer than a frame.

  • VP8

    collect times while playing the video and print a summary to the log afterwards.

    Helixhorned r2832 13 lug, 11:20
  • VP8

    unroll 3 planes -> packed conversion loop.

    Helixhorned r2830 13 lug, 11:20
    Mostra dettagli

    On an AMD Phenom II X4 system with generic memory modules, this brings down the mean time for this conversion from 16.5 to 10.5 ms. (GCC 4.6.1, optimized build)

Apri la build per vedere tutti i 9 commit